Contains I/O related functions.
Contains I/O related functions.
(all-files-by-extension dir ext)Returns all files in dir with the given extension ext.
Returns all files in `dir` with the given extension `ext`.
(load-edn filename)Returns the data from the file named filename.
Returns the data from the file named `filename`.
(load-edn-from-resource filename)Returns the data from the resource named filename.
Returns the data from the resource named `filename`.
(split-path path)Splits a path into a sequence of file entries.
Splits a path into a sequence of file entries.
(windows-path? path)Returns true, if the path is of a windows system.
Returns true, if the path is of a windows system.
(write-json filename data)Writes the data as JSON to filename.
Writes the data as JSON to `filename`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |